Learn R Programming

shinyaframe (version 1.0.1)

aframetags: A-Frame Custom Elements

Description

Functions to output A-Frame's custom HTML elements

Usage

aframeScene(...)

aframeAssets(...)

aframeMixin(...)

aframeEntity(...)

aframeSphere(...)

aframeBox(...)

aframePrimitive(primitive = "entity", ...)

atags

Arguments

...

Attributes, components, and/or child elements

primitive

Primitive name (excluding the "a-")

Format

The atags list contains all of these tag functions for convenient access.

Functions

  • aframeScene: Top level scene entity

  • aframeAssets: Specify assets for pre-loading

  • aframeMixin: Reusable component specifications

  • aframeEntity: Generic entity

  • aframeSphere: Sphere primitive

  • aframeBox: Box primitive

  • aframePrimitive: All other primitives

Details

These functions are just simple wrappers for tag to output common A-Frame custom elements.

See Also

A-Frame Documentation

Examples

Run this code
# NOT RUN {
# Construct A-Frame HTML syntax for a 3D scene with a red box and blue sky
atags$scene(
  atags$box(color = "red", position = "0 0.5 -3"),
  atags$other("sky", color = "#89b6ff")
)

# }

Run the code above in your browser using DataLab