powered by
Functions to output A-Frame's custom HTML elements
aframeScene(...)aframeAssets(...)aframeMixin(...)aframeEntity(...)aframeSphere(...)aframeBox(...)aframePrimitive(primitive = "entity", ...)atags
aframeAssets(...)
aframeMixin(...)
aframeEntity(...)
aframeSphere(...)
aframeBox(...)
aframePrimitive(primitive = "entity", ...)
atags
Attributes, components, and/or child elements
Primitive name (excluding the "a-")
The atags list contains all of these tag functions for convenient access.
aframeScene: Top level scene entity
aframeScene
aframeAssets: Specify assets for pre-loading
aframeAssets
aframeMixin: Reusable component specifications
aframeMixin
aframeEntity: Generic entity
aframeEntity
aframeSphere: Sphere primitive
aframeSphere
aframeBox: Box primitive
aframeBox
aframePrimitive: All other primitives
aframePrimitive
These functions are just simple wrappers for tag to output common A-Frame custom elements.
tag
A-Frame Documentation
# NOT RUN { # Construct A-Frame HTML syntax for a 3D scene with a red box and blue sky atags$scene( atags$box(color = "red", position = "0 0.5 -3"), atags$other("sky", color = "#89b6ff") ) # }
Run the code above in your browser using DataLab